<?php

use ConnectpayPaymentGateway\Includes\CpConstants;

add_action( 'woocommerce_checkout_process', 'add_cp_description_fields_validation' );

function add_cp_description_fields_validation() {
	$first_name_limit      = 50;
	$last_name_limit       = 50;
	$phone_limit           = 15;
	$email_limit           = 250;

	if (
		isset($_POST['checkout_wpnonce'])
		&& wp_verify_nonce(sanitize_key($_POST['checkout_wpnonce']), 'checkout_nonce' )
	) {
		if (isset($_POST['billing_phone']) && !empty( sanitize_text_field($_POST['billing_phone']) )) {
			$filtered_phone_number = preg_replace( '/[^A-Za-z0-9\-]/', '', sanitize_text_field($_POST['billing_phone']) );
		}

		if ( isset($_POST['payment_method']) && 'cp_payment_gateway' === sanitize_text_field($_POST['payment_method']) ) {
			if ( ! isset($_POST['cp_payment_provider'] ) || empty( sanitize_text_field($_POST['cp_payment_provider']) ) ) {
				wc_add_notice( __( 'Please select payment method', CpConstants::CP_TRANSLATIONS ), 'error' );
			}

			if ( isset($_POST['billing_first_name']) && !empty(sanitize_text_field($_POST['billing_first_name'])) &&
				 strlen( sanitize_text_field($_POST['billing_first_name']) ) > $first_name_limit ) {
				wc_add_notice(
					sprintf(
						__( 'First name should not be longer than %s characters', CpConstants::CP_TRANSLATIONS ),
						$first_name_limit
					), 'error'
				);
			}

			if ( isset($_POST['billing_last_name']) && !empty(sanitize_text_field($_POST['billing_last_name'])) &&
				 strlen( sanitize_text_field($_POST['billing_last_name']) ) > $last_name_limit ) {
				wc_add_notice(
					sprintf(
						__( 'Last name should not be longer than %s characters', CpConstants::CP_TRANSLATIONS ),
						$last_name_limit
					), 'error'
				);
			}

			if ( strlen( $filtered_phone_number ) > $phone_limit ) {
				wc_add_notice(
					sprintf(
						__( 'Phone should not be longer than %s characters', CpConstants::CP_TRANSLATIONS ), $phone_limit
					), 'error'
				);
			}

			if ( isset($_POST['billing_email']) && !empty(sanitize_text_field($_POST['billing_email'])) &&
				 strlen( sanitize_text_field($_POST['billing_email']) ) > $email_limit ) {
				wc_add_notice(
					sprintf(
						__( 'Email should not be longer than %s characters', CpConstants::CP_TRANSLATIONS ), $email_limit
					), 'error'
				);
			}

			if ( isset($_POST['billing_first_name']) && !empty(sanitize_text_field($_POST['billing_first_name'])) &&
				 ( preg_match( '/^[\p{L}-]*$/u', sanitize_text_field($_POST['billing_first_name']) ) !== 1 ||
				   preg_match( '/^[\p{L}-]*$/u', sanitize_text_field($_POST['billing_last_name']) ) !== 1 )) {
				wc_add_notice( __( 'No special symbols allowed', CpConstants::CP_TRANSLATIONS ), 'error' );
			}
		}
	}
}

function get_payment_methods_options_list( $payment_methods ) {
	$payment_method_options = [];

	return get_options_list( $payment_methods, $payment_method_options );
}

function get_payment_providers_options_list( $payment_providers_db, $payment_methods, $translations ) {
	$options          = [];
	$payment_country  = get_option( 'cp_payment_country' );
	$is_germany       = WC_CP_Payment_Gateway::PAYMENT_COUNTRY_CODE_GERMANY === $payment_country;
	$is_all_countries = ! empty( get_option( 'cp_is_all_countries' ) );

	if ( isset( $payment_methods['woocommerce_cp_payment_gateway_method_pis'] ) && ! $is_germany && ! $is_all_countries ) {
		foreach ( $payment_providers_db as $key => $provider ) {
			if ( 'yes' === $provider['checked'] ) {
				$provider_logo = $provider['presentation']['logo'];
				$null_logo     = plugins_url() . '/connectpay-payment-gateway/assets/img/nulllogo.png';
				$logo          = is_null( $provider_logo ) ? $null_logo : $provider_logo;
				$provider_name = $provider['name'];

				$html = get_single_payment_provider_html( $key, $logo, $provider_name );

				$options[] = $html;
			}
		}
	} elseif (
		isset( $payment_methods['woocommerce_cp_payment_gateway_method_pis'] ) && ( $is_germany || $is_all_countries )
	) {
		$key           = 'woocommerce_cp_payment_gateway_method_pis';
		$logo          = plugins_url() . '/connectpay-payment-gateway/assets/img/pis.png';
		$provider_name = $translations['by_bank_transfer'];

		$html = get_single_payment_provider_html( $key, $logo, $provider_name );

		$options[] = $html;
	}

	if ( isset( $payment_methods['woocommerce_cp_payment_gateway_method_card'] ) ) {
		$key           = 'woocommerce_cp_payment_gateway_method_card';
		$logo          = plugins_url() . '/connectpay-payment-gateway/assets/img/creditcard.svg';
		$provider_name = $translations['by_card'];

		$html = get_single_payment_provider_html( $key, $logo, $provider_name );

		$options[] = $html;
	}

	return $options;
}

function get_payment_providers_options_list_html( array $payment_provider_options ) {
	ob_start();

	?>
	<p class="form-row form-row form-row-wide validate-required" id="cp_payment_provider_field" data-priority=""
		style="">
			<span class="woocommerce-input-wrapper">
				<?php
				foreach ( $payment_provider_options as $provider ) {
					echo wp_kses($provider, array_merge(
							[
									'input' => [
											'type'  => true,
											'value' => true,
											'id'    => true,
											'class' => true,
											'name'  => true,
									],
							],
							wp_kses_allowed_html( 'post' )
					));
				}
				?>
			</span>
	</p>
	<?php

	return ob_get_clean();
}

function get_single_payment_provider_html( $key, $logo, $provider_name ) {
	ob_start();

	?>
	<input type="radio"
		   class="input-radio cp_payment_provider_radio"
		   value="<?php echo esc_attr($key); ?>"
		   name="cp_payment_provider"
		   id="<?php echo esc_attr($key); ?>"
	>
	<label for="<?php echo esc_attr($key); ?>" class="radio cp_payment_provider_label">
		<img class="cp_payment_provider_logo" alt="Payment provider logo" src="<?php echo esc_attr($logo); ?>"/>
		<span class="cp_payment_provider_name"><strong><?php echo esc_attr($provider_name); ?></strong></span>
	</label>
	<?php
	return ob_get_clean();
}

function get_options_list( $values, $options ) {
	foreach ( $values as $key => $value ) {
		if ( 'yes' === $value ) {
			$option_name     = strtoupper( explode( '_', $key )[5] );
			$options[ $key ] = __( $option_name, CpConstants::CP_TRANSLATIONS );
		}
	}

	return $options;
}
