<?php

$pagePath = explode( '/wp-content/', dirname( __FILE__ ) );

require_once( $pagePath[0] . '/wp-load.php' );
require_once WP_PLUGIN_DIR . '/connectpay-payment-gateway/includes/scripts/cp-get-payment-details-method.php';

add_action( 'cp_payment_details_checker', 'cp_check_payment_details', 1, 2 );

function cp_check_payment_details( $order_id, $repeating ) {
	$order = wc_get_order( $order_id );

	if ( ! $order ) {
		wp_clear_scheduled_hook( 'cp_payment_details_checker', [ 'order_id' => $order_id, 'repeating' => true ] );
		return;
	}

	$is_terminal_meta = $order->get_meta( 'cp_is_terminal' );
	$payment_id       = $order->get_meta( 'cp_payment_id' );

	if ( 'true' === $is_terminal_meta || empty( $payment_id ) ) {
		wp_clear_scheduled_hook( 'cp_payment_details_checker', [ 'order_id' => $order_id, 'repeating' => true ] );
	} else {
		$response = get_payment_details_method( $payment_id );

		if ( isset( $response['error'] ) && ! empty( $response['error'] ) ) {
			$logger = wc_get_logger();
			$logger->error(
				print_r( [
					'type'     => 'Cron Event',
					'order_id' => $order_id,
					'response' => $response
				], true )
			);
		} else {
			$is_terminal = $response['status']['isTerminal'];

			if ( $is_terminal ) {
				wp_clear_scheduled_hook( 'cp_payment_details_checker', [ 'order_id'  => $order_id,
																		'repeating' => true
				] );
			}
		}
	}
}

add_action( 'woocommerce_new_order', 'scheduler_activation', 1, 1 );

function scheduler_activation( $order_id ) {
	$new_time_four_hours = gmdate( 'Y-m-d H:i:s', strtotime( '+4 hours' ) );

	//	For testing purposes
	/**
	 * There were two cron jobs, second one was uneccessary to keep so it was deleted with task PHP-228.
	 */
	$timestamp_four_hours = ( new DateTime( $new_time_four_hours ) )->getTimestamp();

	if ( ! wp_next_scheduled( 'cp_payment_details_checker' ) ) {
		wp_schedule_event( $timestamp_four_hours, 'hourly', 'cp_payment_details_checker', [
			'order_id'  => $order_id,
			'repeating' => true
		] );
	}
}
